@@ -3,19 +3,19 @@
  * Copyright (C) 2012 Red Hat
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA
  *
  * Written by:
  *     Jasper St. Pierre <jstpierre@mecheye.net>
@@ -45,6 +45,7 @@ static GParamSpec *obj_props[PROP_LAST];
 
 enum {
   PREPARE,
+  NEXT_PAGE,
   LAST_SIGNAL,
 };
 
@@ -132,6 +133,15 @@ gis_assistant_switch_to (GisAssistant *assistant, GtkWidget *widget)
 
 void
 gis_assistant_next_page (GisAssistant *assistant)
+{
+  GisAssistantPrivate *priv = assistant->priv;
+  g_signal_emit (assistant, signals[NEXT_PAGE], 0,
+                 priv->current_page->widget);
+}
+
+static void
+gis_assistant_real_next_page (GisAssistant *assistant,
+                              GtkWidget    *leaving_page)
 {
   GisAssistantPrivate *priv = assistant->priv;
   PageData *next_page;
@@ -154,7 +164,7 @@ gis_assistant_previous_page (GisAssistant *assistant)
   gis_assistant_switch_to (assistant, prev_page->widget);
 }
 
-static void
+ static void
 update_navigation_buttons (GisAssistant *assistant,
                            GtkWidget    *page)
 {
@@ -423,6 +433,7 @@ gis_assistant_class_init (GisAssistantClass *klass)
   gobject_class->finalize = gis_assistant_finalize;
 
   klass->prepare = gis_assistant_prepare;
+  klass->next_page = gis_assistant_real_next_page;
 
   obj_props[PROP_TITLE] =
     g_param_spec_string ("title",
@@ -430,6 +441,22 @@ gis_assistant_class_init (GisAssistantClass *klass)
                          NULL,
                          G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
+  /**
+   * GisAssistant::next-page:
+   * @assistant: the #GisAssistant
+   * @page: the page we're leaving
+   *
+   * The ::next-page signal is emitted when we're leaving
+   * a page, allowing a page to do something when it's left.
+   */
+  signals[NEXT_PAGE] =
+    g_signal_new ("next-page",
+                  G_TYPE_FROM_CLASS (gobject_class),
+                  G_SIGNAL_RUN_LAST,
+                  G_STRUCT_OFFSET (GisAssistantClass, next_page),
+                  NULL, NULL, NULL,
+                  G_TYPE_NONE, 1, GTK_TYPE_WIDGET);
+
   /**
    * GisAssistant::prepare:
    * @assistant: the #GisAssistant
@@ -446,7 +473,7 @@ gis_assistant_class_init (GisAssistantClass *klass)
                   G_TYPE_FROM_CLASS (gobject_class),
                   G_SIGNAL_RUN_LAST,
                   G_STRUCT_OFFSET (GisAssistantClass, prepare),
-                  NULL, NULL,
-                  g_cclosure_marshal_VOID__OBJECT,
+                  NULL, NULL, NULL,
                   G_TYPE_NONE, 1, GTK_TYPE_WIDGET);
+
 }
