@@ -5,9 +5,15 @@
 
 #include <gio/gio.h>
 
-#define SKELETON_DIR "/dev/shm/gnome-initial-setup/skeleton"
+#define SKELETON_PATH "gnome-initial-setup/skeleton"
 
-static gboolean
+static char *
+get_skeleton_dir (void)
+{
+  return g_build_filename (g_get_user_runtime_dir (), SKELETON_PATH, NULL);
+}
+
+static void
 move_file_from_tmpfs (GFile *src_base,
                       const gchar *dir,
                       const gchar *path)
@@ -21,25 +27,19 @@ move_file_from_tmpfs (GFile *src_base,
 
   if (!g_file_move (src, dest, G_FILE_COPY_NONE,
                     NULL, NULL, NULL, &error)) {
-    g_warning ("Unable to move %s to %s: %s",
-               g_file_get_path (src),
-               g_file_get_path (dest),
-               error->message);
-    goto out;
+    if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND)) {
+      g_warning ("Unable to move %s to %s: %s",
+                 g_file_get_path (src),
+                 g_file_get_path (dest),
+                 error->message);
+    }
+    g_error_free (error);
   }
 
- out:
   g_object_unref (dest_dir);
   g_object_unref (dest);
   g_object_unref (src);
   g_free (basename);
-
-  if (error != NULL) {
-    g_error_free (error);
-    return FALSE;
-  } else {
-    return TRUE;
-  }
 }
 
 int
@@ -52,20 +52,20 @@ main (int    argc,
 
   g_type_init ();
 
-  src = g_file_new_for_path (SKELETON_DIR);
+  src = g_file_new_for_path (get_skeleton_dir ());
 
-  if (g_file_query_exists (src, NULL))
+  if (!g_file_query_exists (src, NULL))
     goto out;
 
   ret = 1;
 
-#define MOVE(d, x)                                                      \
-  if (!move_file_from_tmpfs (src, g_get_user_##d##_dir (), x))          \
-    goto out;
+#define FILE(d, x) \
+  move_file_from_tmpfs (src, g_get_user_##d##_dir (), x)
 
-  MOVE (config, "dconf/user");
-  MOVE (config, "goa-1.0/accounts.conf");
-  MOVE (data, "keyrings/Default.keyring");
+  FILE (config, "run-welcome-tour");
+  FILE (config, "dconf/user");
+  FILE (config, "goa-1.0/accounts.conf");
+  FILE (data, "keyrings/Default.keyring");
 
   if (!g_file_delete (src, NULL, &error))
     {
